#[repr(C)]pub struct WrappedArray {
pub array: FFI_ArrowArray,
pub schema: WrappedSchema,
}Expand description
This is a wrapper struct for FFI_ArrowArray to indicate that the struct is FFI Safe. For convenience, we also include the schema needed to create a record batch from the array.
Fields
array: FFI_ArrowArrayschema: WrappedSchemaTrait Implementations
Sourceimpl Debug for WrappedArray
impl Debug for WrappedArray
Sourceimpl TryFrom<&ScalarValue> for WrappedArray
impl TryFrom<&ScalarValue> for WrappedArray
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<WrappedArray> for ArrayRef
impl TryFrom<WrappedArray> for ArrayRef
Sourcetype Error = ArrowError
type Error = ArrowError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<WrappedArray> for ScalarValue
impl TryFrom<WrappedArray> for ScalarValue
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.