#[repr(C)]pub struct FFI_TaskContext {
pub session_id: unsafe extern "C" fn(&Self) -> String,
pub task_id: unsafe extern "C" fn(&Self) -> FFI_Option<String>,
pub session_config: unsafe extern "C" fn(&Self) -> FFI_SessionConfig,
pub scalar_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_ScalarUDF)>,
pub aggregate_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_AggregateUDF)>,
pub window_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_WindowUDF)>,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Expand description
A stable struct for sharing TaskContext across FFI boundaries.
Fields
session_id: unsafe extern "C" fn(&Self) -> StringReturn the session ID.
task_id: unsafe extern "C" fn(&Self) -> FFI_Option<String>Return the task ID.
session_config: unsafe extern "C" fn(&Self) -> FFI_SessionConfigReturn the session configuration.
scalar_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_ScalarUDF)>Returns a vec of name-function pairs for scalar functions.
aggregate_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_AggregateUDF)>Returns a vec of name-function pairs for aggregate functions.
window_functions: unsafe extern "C" fn(&Self) -> Vec<(String, FFI_WindowUDF)>Returns a vec of name-function pairs for window functions.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the plan. The foreign library should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through
the foreign interface. See crate::get_library_marker_id and
the crate’s README.md for more information.