Module task_ctx_provider

Module task_ctx_provider 

Structs

FFI_TaskContextProvider
Struct for accessing the TaskContext. This method contains a weak reference, so there are no guarantees that the TaskContext remains valid. This is used primarily for protobuf encoding and decoding of data passed across the FFI boundary. See the crate README for additional information.