Modules
- tests
integration-tests
Structs
- Execution
Plan Private Data - FFI_
Execution Plan - A stable struct for sharing a
ExecutionPlanacross FFI boundaries. - Foreign
Execution Plan - This struct is used to access an execution plan provided by a foreign library across a FFI boundary.