pub struct FFI_ExponentialDistribution { /* private fields */ }Trait Implementations
Sourceimpl Debug for FFI_ExponentialDistribution
impl Debug for FFI_ExponentialDistribution
Sourceimpl TryFrom<&ExponentialDistribution> for FFI_ExponentialDistribution
impl TryFrom<&ExponentialDistribution> for FFI_ExponentialDistribution
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<FFI_ExponentialDistribution> for Distribution
impl TryFrom<FFI_ExponentialDistribution> for Distribution
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.