pub struct FFI_UniformDistribution { /* private fields */ }Trait Implementations
Sourceimpl Debug for FFI_UniformDistribution
impl Debug for FFI_UniformDistribution
Sourceimpl TryFrom<&UniformDistribution> for FFI_UniformDistribution
impl TryFrom<&UniformDistribution> for FFI_UniformDistribution
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<FFI_UniformDistribution> for Distribution
impl TryFrom<FFI_UniformDistribution> for Distribution
Sourcetype Error = DataFusionError
type Error = DataFusionError
The type returned in the event of a conversion error.