sresult_return

Macro sresult_return 

macro_rules! sresult_return {
    ( $x:expr ) => { ... };
}
This macro is a helpful conversion utility to convert from a DataFusion Result to an FFI_Result and to also call return when it is an error. Since you cannot use ? on an FFI_Result, this is designed to mimic the pattern.