#[repr(C)]pub struct FFI_PhysicalExpr {Show 23 fields
pub data_type: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<WrappedSchema>,
pub nullable: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<bool>,
pub evaluate: unsafe extern "C" fn(_: &Self, batch: WrappedArray) -> FFI_Result<FFI_ColumnarValue>,
pub return_field: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<WrappedSchema>,
pub evaluate_selection: unsafe extern "C" fn(_: &Self, batch: WrappedArray, selection: WrappedArray) -> FFI_Result<FFI_ColumnarValue>,
pub children: unsafe extern "C" fn(&Self) -> Vec<FFI_PhysicalExpr>,
pub new_with_children: unsafe extern "C" fn(_: &Self, children: &Vec<FFI_PhysicalExpr>) -> FFI_Result<Self>,
pub evaluate_bounds: unsafe extern "C" fn(_: &Self, children: Vec<FFI_Interval>) -> FFI_Result<FFI_Interval>,
pub propagate_constraints: unsafe extern "C" fn(_: &Self, interval: FFI_Interval, children: Vec<FFI_Interval>) -> FFI_Result<FFI_Option<Vec<FFI_Interval>>>,
pub evaluate_statistics: unsafe extern "C" fn(_: &Self, children: Vec<FFI_Distribution>) -> FFI_Result<FFI_Distribution>,
pub propagate_statistics: unsafe extern "C" fn(_: &Self, parent: FFI_Distribution, children: Vec<FFI_Distribution>) -> FFI_Result<FFI_Option<Vec<FFI_Distribution>>>,
pub get_properties: unsafe extern "C" fn(_: &Self, children: Vec<FFI_ExprProperties>) -> FFI_Result<FFI_ExprProperties>,
pub fmt_sql: unsafe extern "C" fn(&Self) -> FFI_Result<String>,
pub snapshot: unsafe extern "C" fn(&Self) -> FFI_Result<FFI_Option<FFI_PhysicalExpr>>,
pub snapshot_generation: unsafe extern "C" fn(&Self) -> u64,
pub is_volatile_node: unsafe extern "C" fn(&Self) -> bool,
pub display: unsafe extern "C" fn(&Self) -> String,
pub hash: unsafe extern "C" fn(&Self) -> u64,
pub clone: unsafe extern "C" fn(plan: &Self) -> Self,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub version: unsafe extern "C" fn() -> u64,
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Fields
data_type: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<WrappedSchema>nullable: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<bool>evaluate: unsafe extern "C" fn(_: &Self, batch: WrappedArray) -> FFI_Result<FFI_ColumnarValue>return_field: unsafe extern "C" fn(_: &Self, input_schema: WrappedSchema) -> FFI_Result<WrappedSchema>evaluate_selection: unsafe extern "C" fn(_: &Self, batch: WrappedArray, selection: WrappedArray) -> FFI_Result<FFI_ColumnarValue>children: unsafe extern "C" fn(&Self) -> Vec<FFI_PhysicalExpr>new_with_children: unsafe extern "C" fn(_: &Self, children: &Vec<FFI_PhysicalExpr>) -> FFI_Result<Self>evaluate_bounds: unsafe extern "C" fn(_: &Self, children: Vec<FFI_Interval>) -> FFI_Result<FFI_Interval>propagate_constraints: unsafe extern "C" fn(_: &Self, interval: FFI_Interval, children: Vec<FFI_Interval>) -> FFI_Result<FFI_Option<Vec<FFI_Interval>>>evaluate_statistics: unsafe extern "C" fn(_: &Self, children: Vec<FFI_Distribution>) -> FFI_Result<FFI_Distribution>propagate_statistics: unsafe extern "C" fn(_: &Self, parent: FFI_Distribution, children: Vec<FFI_Distribution>) -> FFI_Result<FFI_Option<Vec<FFI_Distribution>>>get_properties: unsafe extern "C" fn(_: &Self, children: Vec<FFI_ExprProperties>) -> FFI_Result<FFI_ExprProperties>fmt_sql: unsafe extern "C" fn(&Self) -> FFI_Result<String>snapshot: unsafe extern "C" fn(&Self) -> FFI_Result<FFI_Option<FFI_PhysicalExpr>>snapshot_generation: unsafe extern "C" fn(&Self) -> u64is_volatile_node: unsafe extern "C" fn(&Self) -> booldisplay: unsafe extern "C" fn(&Self) -> Stringhash: unsafe extern "C" fn(&Self) -> u64clone: unsafe extern "C" fn(plan: &Self) -> SelfUsed to create a clone on the provider of the execution plan. This should only need to be called by the receiver of the plan.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
version: unsafe extern "C" fn() -> u64Return the major DataFusion version number of this provider.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the plan.
A ForeignPhysicalExpr should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through the foreign interface.