ForeignPhysicalExpr

Struct ForeignPhysicalExpr 

pub struct ForeignPhysicalExpr { /* private fields */ }
This wrapper struct exists on the receiver side of the FFI interface, so it has no guarantees about being able to access the data in private_data. Any functions defined on this struct must only use the stable functions provided in FFI_PhysicalExpr to interact with the expression.