ForeignPhysicalOptimizerRule

Struct ForeignPhysicalOptimizerRule 

pub struct ForeignPhysicalOptimizerRule { /* private fields */ }
This wrapper struct exists on the receiver side of the FFI interface, so it has no guarantees about being able to access the data in private_data. Any functions defined on this struct must only use the stable functions provided in FFI_PhysicalOptimizerRule to interact with the foreign rule.