pub struct FFI_PhysicalExtensionCodec {
pub clone: unsafe extern "C" fn(plan: &Self) -> Self,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub version: unsafe extern "C" fn() -> u64,
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
/* private fields */
}Expand description
A stable struct for sharing PhysicalExtensionCodec across FFI boundaries.
Fields
clone: unsafe extern "C" fn(plan: &Self) -> SelfUsed to create a clone on the provider of the execution plan. This should only need to be called by the receiver of the plan.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
version: unsafe extern "C" fn() -> u64Return the major DataFusion version number of this provider.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the plan.
A ForeignPhysicalExtensionCodec should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through the foreign interface.
Implementations
Sourceimpl FFI_PhysicalExtensionCodec
impl FFI_PhysicalExtensionCodec
Sourcepub fn new(
codec: Arc<dyn PhysicalExtensionCodec + Send>,
runtime: Option<Handle>,
task_ctx_provider: impl Into<FFI_TaskContextProvider>,
) -> Self
pub fn new( codec: Arc<dyn PhysicalExtensionCodec + Send>, runtime: Option<Handle>, task_ctx_provider: impl Into<FFI_TaskContextProvider>, ) -> Self
Creates a new FFI_PhysicalExtensionCodec.