pub struct ForeignPhysicalExtensionCodec(pub FFI_PhysicalExtensionCodec);Expand description
This wrapper struct exists on the receiver side of the FFI interface, so it has
no guarantees about being able to access the data in private_data. Any functions
defined on this struct must only use the stable functions provided in
FFI_PhysicalExtensionCodec to interact with the foreign table provider.
Tuple Fields
0: FFI_PhysicalExtensionCodecTrait Implementations
Sourceimpl PhysicalExtensionCodec for ForeignPhysicalExtensionCodec
impl PhysicalExtensionCodec for ForeignPhysicalExtensionCodec
fn try_decode( &self, buf: &[u8], inputs: &[Arc<dyn ExecutionPlan>], _ctx: &TaskContext, ) -> Result<Arc<dyn ExecutionPlan>>
fn try_encode( &self, node: Arc<dyn ExecutionPlan>, buf: &mut Vec<u8>, ) -> Result<()>
fn try_decode_udf(&self, name: &str, buf: &[u8]) -> Result<Arc<ScalarUDF>>
fn try_encode_udf(&self, node: &ScalarUDF, buf: &mut Vec<u8>) -> Result<()>
fn try_decode_udaf(&self, name: &str, buf: &[u8]) -> Result<Arc<AggregateUDF>>
fn try_encode_udaf(&self, node: &AggregateUDF, buf: &mut Vec<u8>) -> Result<()>
fn try_decode_udwf(&self, name: &str, buf: &[u8]) -> Result<Arc<WindowUDF>>
fn try_encode_udwf(&self, node: &WindowUDF, buf: &mut Vec<u8>) -> Result<()>
fn try_decode_expr( &self, _buf: &[u8], _inputs: &[Arc<dyn PhysicalExpr>], ) -> Result<Arc<dyn PhysicalExpr>, DataFusionError>
fn try_encode_expr( &self, _node: &Arc<dyn PhysicalExpr>, _buf: &mut Vec<u8>, ) -> Result<(), DataFusionError>
impl Send for ForeignPhysicalExtensionCodec
impl Sync for ForeignPhysicalExtensionCodec