#[repr(C)]pub struct FFI_SessionConfig {
pub config_options: FFI_ConfigOptions,
pub clone: unsafe extern "C" fn(plan: &Self) -> Self,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Expand description
A stable struct for sharing SessionConfig across FFI boundaries.
Instead of attempting to expose the entire SessionConfig interface, we
convert the config options into a map from a string to string and pass
those values across the FFI boundary. On the receiver side, we
reconstruct a SessionConfig from those values.
It is possible that using different versions of DataFusion across the FFI boundary could have differing expectations of the config options. This is a limitation of this approach, but exposing the entire SessionConfig via a FFI interface would be extensive and provide limited value over this version.
Fields
config_options: FFI_ConfigOptionsFFI stable configuration options.
clone: unsafe extern "C" fn(plan: &Self) -> SelfUsed to create a clone on the provider of the execution plan. This should only need to be called by the receiver of the plan.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the plan.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through
the foreign interface. See crate::get_library_marker_id and
the crate’s README.md for more information.