ForeignSession

Struct ForeignSession 

pub struct ForeignSession { /* private fields */ }
This wrapper struct exists on the receiver side of the FFI interface, so it has no guarantees about being able to access the data in private_data. Any functions defined on this struct must use only the stable function pointers in FFI_SessionRef to interact with the foreign session.

Query planner delegation

If the session owner installed the current foreign query planner, Session::create_physical_plan dispatches back to that planner and Session::query_planner returns that planner. The planner must retain and invoke the session owner’s previous planner instead of using either method to delegate back to the session. Otherwise, repeated delegation exhausts the stack. See crate::query_planner for details.