pub struct ForeignTableProviderFactory(pub FFI_TableProviderFactory);Expand description
This wrapper struct exists on the receiver side of the FFI interface, so it has
no guarantees about being able to access the data in private_data. Any functions
defined on this struct must only use the stable functions provided in
FFI_TableProviderFactory to interact with the foreign table provider factory.
Tuple Fields
0: FFI_TableProviderFactoryTrait Implementations
Sourceimpl Debug for ForeignTableProviderFactory
impl Debug for ForeignTableProviderFactory
impl Send for ForeignTableProviderFactory
impl Sync for ForeignTableProviderFactory
Sourceimpl TableProviderFactory for ForeignTableProviderFactory
impl TableProviderFactory for ForeignTableProviderFactory
Sourcefn create<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
session: &'life1 dyn Session,
cmd: &'life2 CreateExternalTable,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn TableProvider>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn create<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
session: &'life1 dyn Session,
cmd: &'life2 CreateExternalTable,
) -> Pin<Box<dyn Future<Output = Result<Arc<dyn TableProvider>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Create a TableProvider with the given url