FixedCatalogProviderList

Struct FixedCatalogProviderList 

pub struct FixedCatalogProviderList { /* private fields */ }
Available on crate feature integration-tests only.
This catalog provider list is intended only for unit tests. It prepopulates with one catalog and only allows for catalogs named after four colors.