#[unsafe(no_mangle)]pub extern "C" fn datafusion_ffi_get_module() -> ForeignLibraryModuleAvailable on crate feature
integration-tests only.Expand description
This defines the entry point for using the module.
#[unsafe(no_mangle)]pub extern "C" fn datafusion_ffi_get_module() -> ForeignLibraryModuleintegration-tests only.This defines the entry point for using the module.