ForeignLibraryModule

Struct ForeignLibraryModule 

#[repr(C)]
pub struct ForeignLibraryModule {
Show 17 fields pub create_catalog: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_CatalogProvider, pub create_catalog_list: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_CatalogProviderList, pub create_table: extern "C" fn(synchronous: bool, codec: FFI_LogicalExtensionCodec) -> FFI_TableProvider, pub create_table_factory: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_TableProviderFactory, pub create_scalar_udf: extern "C" fn() -> FFI_ScalarUDF, pub create_nullary_udf: extern "C" fn() -> FFI_ScalarUDF, pub create_timezone_udf: extern "C" fn() -> FFI_ScalarUDF, pub create_table_function: extern "C" fn(FFI_LogicalExtensionCodec) -> FFI_TableFunction, pub create_sum_udaf: extern "C" fn() -> FFI_AggregateUDF, pub create_stddev_udaf: extern "C" fn() -> FFI_AggregateUDF, pub create_rank_udwf: extern "C" fn() -> FFI_WindowUDF, pub create_extension_options: extern "C" fn() -> FFI_ExtensionOptions, pub create_empty_exec: extern "C" fn() -> FFI_ExecutionPlan, pub create_exec_with_statistics: extern "C" fn() -> FFI_ExecutionPlan, pub create_table_with_statistics: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_TableProvider, pub create_physical_optimizer_rule: extern "C" fn() -> FFI_PhysicalOptimizerRule, pub version: extern "C" fn() -> u64,
}
Available on crate feature integration-tests only.
This struct defines the module interfaces. It is to be shared by both the module loading program and library that implements the module.

Fields

create_catalog: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_CatalogProvider

Construct an opinionated catalog provider

create_catalog_list: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_CatalogProviderList

Construct an opinionated catalog provider list

create_table: extern "C" fn(synchronous: bool, codec: FFI_LogicalExtensionCodec) -> FFI_TableProvider

Constructs the table provider

create_table_factory: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_TableProviderFactory

Constructs the table provider factory

create_scalar_udf: extern "C" fn() -> FFI_ScalarUDF

Create a scalar UDF

create_nullary_udf: extern "C" fn() -> FFI_ScalarUDFcreate_timezone_udf: extern "C" fn() -> FFI_ScalarUDFcreate_table_function: extern "C" fn(FFI_LogicalExtensionCodec) -> FFI_TableFunctioncreate_sum_udaf: extern "C" fn() -> FFI_AggregateUDF

Create an aggregate UDAF using sum

create_stddev_udaf: extern "C" fn() -> FFI_AggregateUDF

Create grouping UDAF using stddev

create_rank_udwf: extern "C" fn() -> FFI_WindowUDFcreate_extension_options: extern "C" fn() -> FFI_ExtensionOptions

Create extension options, for either ConfigOptions or TableOptions

create_empty_exec: extern "C" fn() -> FFI_ExecutionPlancreate_exec_with_statistics: extern "C" fn() -> FFI_ExecutionPlancreate_table_with_statistics: extern "C" fn(codec: FFI_LogicalExtensionCodec) -> FFI_TableProvidercreate_physical_optimizer_rule: extern "C" fn() -> FFI_PhysicalOptimizerRuleversion: extern "C" fn() -> u64