ForeignWindowUDF

Struct ForeignWindowUDF 

pub struct ForeignWindowUDF { /* private fields */ }
This struct is used to access an UDF provided by a foreign library across a FFI boundary.

The ForeignWindowUDF is to be used by the caller of the UDF, so it has no knowledge or access to the private data. All interaction with the UDF must occur through the functions defined in FFI_WindowUDF.