Module util

Module util 

Functions

rvec_wrapped_to_vec_datatype
This is a utility function to convert an FFI friendly vector of WrappedSchema to their equivalent DataType.
rvec_wrapped_to_vec_fieldref
This is a utility function to convert an FFI friendly vector of WrappedSchema to their equivalent Field.
vec_datatype_to_rvec_wrapped
This is a utility function to convert a slice of DataType to its equivalent FFI friendly counterpart, WrappedSchema
vec_fieldref_to_rvec_wrapped
This is a utility function to convert a slice of Field to its equivalent FFI friendly counterpart, WrappedSchema

Type Aliases

FFIResult
Convenience type for results passed through the FFI boundary. Since the DataFusionError enum is complex and little value is gained from creating a FFI safe variant of it, we convert errors to strings when passing results back. These are converted back and forth using the df_result, rresult, and rresult_return macros.