Modules
- arrow_
wrappers - catalog_
provider - catalog_
provider_ list - config
- execution
- execution_
plan - expr
- ffi_
option - FFI-safe Option and Result types that do not require
IStablebounds. - insert_
op - physical_
expr - physical_
optimizer - plan_
properties - proto
- record_
batch_ stream - schema_
provider - session
- statistics
- Helpers for moving
Statisticsacross the FFI boundary as prost-encodeddatafusion_proto_common::Statisticsbytes. - table_
provider - table_
provider_ factory - table_
source - tests
integration-tests - udaf
- udf
- udtf
- udwf
- util
- volatility
Macros
- df_
result - This macro is a helpful conversion utility to convert from an FFI_Result to a DataFusion result.
- sresult
- This macro is a helpful conversion utility to convert from a DataFusion Result to an FFI_Result.
- sresult_
return - This macro is a helpful conversion utility to convert from a DataFusion Result to an FFI_Result
and to also call return when it is an error. Since you cannot use
?on an FFI_Result, this is designed to mimic the pattern.
Functions
- get_
library_ marker_ id - This utility is used to determine if two FFI structs are within the same library. It is possible that the interplay between foreign and local functions calls create one FFI struct that references another. It is helpful to determine if a foreign struct in the same library or called from a different one. If we are in the same library, then we can access the underlying types directly.
- version
- Returns the major version of the FFI implementation. If the API evolves, we use the major version to identify compatibility over the unsafe boundary. This call is intended to be used by implementers to validate they have compatible libraries.