Structs
- FFI_
Task Context Provider - Struct for accessing the
TaskContext. This method contains a weak reference, so there are no guarantees that theTaskContextremains valid. This is used primarily for protobuf encoding and decoding of data passed across the FFI boundary. See the crate README for additional information.