#[repr(C)]pub struct FFI_TaskContextProvider {
pub task_ctx: unsafe extern "C" fn(&Self) -> FFI_Result<FFI_TaskContext>,
pub clone: unsafe extern "C" fn(plan: &Self) -> Self,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Expand description
Struct for accessing the TaskContext. This method contains a weak
reference, so there are no guarantees that the TaskContext remains
valid. This is used primarily for protobuf encoding and decoding of
data passed across the FFI boundary. See the crate README for
additional information.
Fields
task_ctx: unsafe extern "C" fn(&Self) -> FFI_Result<FFI_TaskContext>Retrieve the current TaskContext provided the provider has not
gone out of scope. This function will return an error if the weakly
held reference to the underlying TaskContextProvider is no longer
available.
clone: unsafe extern "C" fn(plan: &Self) -> SelfUsed to create a clone on the task context accessor. This should only need to be called by the receiver of the plan.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the plan. The foreign library should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through
the foreign interface. See crate::get_library_marker_id and
the crate’s README.md for more information.