#[repr(C)]pub struct FFI_PhysicalOptimizerRule {
pub optimize: unsafe extern "C" fn(_: &Self, plan: &FFI_ExecutionPlan, config: FFI_ConfigOptions) -> FFI_Result<FFI_ExecutionPlan>,
pub name: unsafe extern "C" fn(&Self) -> String,
pub schema_check: unsafe extern "C" fn(&Self) -> bool,
pub clone: unsafe extern "C" fn(plan: &Self) -> Self,
pub release: unsafe extern "C" fn(arg: &mut Self),
pub version: unsafe extern "C" fn() -> u64,
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Expand description
A stable struct for sharing PhysicalOptimizerRule across FFI boundaries.
Fields
optimize: unsafe extern "C" fn(_: &Self, plan: &FFI_ExecutionPlan, config: FFI_ConfigOptions) -> FFI_Result<FFI_ExecutionPlan>name: unsafe extern "C" fn(&Self) -> Stringschema_check: unsafe extern "C" fn(&Self) -> boolclone: unsafe extern "C" fn(plan: &Self) -> SelfUsed to create a clone on the rule. This should only need to be called by the receiver of the plan.
release: unsafe extern "C" fn(arg: &mut Self)Release the memory of the private data when it is no longer being used.
version: unsafe extern "C" fn() -> u64Return the major DataFusion version number of this rule.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the rule.
A ForeignPhysicalOptimizerRule should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through the foreign interface.
Implementations
Sourceimpl FFI_PhysicalOptimizerRule
impl FFI_PhysicalOptimizerRule
Sourcepub fn new(
rule: Arc<dyn PhysicalOptimizerRule + Send + Sync>,
runtime: Option<Handle>,
) -> Self
pub fn new( rule: Arc<dyn PhysicalOptimizerRule + Send + Sync>, runtime: Option<Handle>, ) -> Self
Creates a new FFI_PhysicalOptimizerRule.