pub struct ForeignLogicalExtensionCodec(pub FFI_LogicalExtensionCodec);Expand description
This wrapper struct exists on the receiver side of the FFI interface, so it has
no guarantees about being able to access the data in private_data. Any functions
defined on this struct must only use the stable functions provided in
FFI_LogicalExtensionCodec to interact with the foreign table provider.
Tuple Fields
0: FFI_LogicalExtensionCodecTrait Implementations
Sourceimpl Debug for ForeignLogicalExtensionCodec
impl Debug for ForeignLogicalExtensionCodec
Sourceimpl LogicalExtensionCodec for ForeignLogicalExtensionCodec
impl LogicalExtensionCodec for ForeignLogicalExtensionCodec
fn try_decode( &self, _buf: &[u8], _inputs: &[LogicalPlan], _ctx: &TaskContext, ) -> Result<Extension>
fn try_encode(&self, _node: &Extension, _buf: &mut Vec<u8>) -> Result<()>
fn try_decode_table_provider( &self, buf: &[u8], table_ref: &TableReference, schema: SchemaRef, _ctx: &TaskContext, ) -> Result<Arc<dyn TableProvider>>
fn try_encode_table_provider( &self, table_ref: &TableReference, node: Arc<dyn TableProvider>, buf: &mut Vec<u8>, ) -> Result<()>
fn try_decode_file_format( &self, _buf: &[u8], _ctx: &TaskContext, ) -> Result<Arc<dyn FileFormatFactory>>
fn try_encode_file_format( &self, _buf: &mut Vec<u8>, _node: Arc<dyn FileFormatFactory>, ) -> Result<()>
fn try_decode_udf(&self, name: &str, buf: &[u8]) -> Result<Arc<ScalarUDF>>
fn try_encode_udf(&self, node: &ScalarUDF, buf: &mut Vec<u8>) -> Result<()>
fn try_decode_udaf(&self, name: &str, buf: &[u8]) -> Result<Arc<AggregateUDF>>
fn try_encode_udaf(&self, node: &AggregateUDF, buf: &mut Vec<u8>) -> Result<()>
fn try_decode_udwf(&self, name: &str, buf: &[u8]) -> Result<Arc<WindowUDF>>
fn try_encode_udwf(&self, node: &WindowUDF, buf: &mut Vec<u8>) -> Result<()>
impl Send for ForeignLogicalExtensionCodec
impl Sync for ForeignLogicalExtensionCodec