Available on crate feature
integration-tests only.Modules
- catalog
- This is an example of an async table provider that will call functions on the tokio runtime of the library providing the function. Since we cannot share a tokio runtime across the ffi boundary and the producer and consumer may have different runtimes, we need to store a reference to the runtime and enter it during streaming calls. The entering of the runtime will occur by the datafusion_ffi crate during the streaming calls. This code serves as an integration test of this feature. If we do not correctly access the runtime, then you will get a panic when trying to do operations such as spawning a tokio task.
- utils
Structs
- Foreign
Library Module - This struct defines the module interfaces. It is to be shared by both the module loading program and library that implements the module.
- Foreign
Library Module Ref - This is the pointer to the prefix of
ForeignLibraryModule. - Foreign
Library Module_ Prefix - This is the prefix fields of
ForeignLibraryModule, accessible throughForeignLibraryModuleRef, with.0.prefix().
Statics
Functions
- create_
record_ batch - create_
test_ schema - get_
foreign_ library_ module - This defines the entry point for using the module.