pub struct FixedSchemaProvider { /* private fields */ }Available on crate feature
integration-tests only.Expand description
This schema provider is intended only for unit tests. It prepopulates with one table and only allows for tables named sales and purchases.