ForeignTableFunction

Struct ForeignTableFunction 

pub struct ForeignTableFunction(/* private fields */);
This struct is used to access an UDTF provided by a foreign library across a FFI boundary.

The ForeignTableFunction is to be used by the caller of the UDTF, so it has no knowledge or access to the private data. All interaction with the UDTF must occur through the functions defined in FFI_TableFunction.