#[repr(C)]pub struct FFI_WindowUDF {
pub name: String,
pub aliases: Vec<String>,
pub volatility: FFI_Volatility,
pub partition_evaluator: unsafe extern "C" fn(udwf: &Self, args: FFI_PartitionEvaluatorArgs) -> FFI_Result<FFI_PartitionEvaluator>,
pub field: unsafe extern "C" fn(udwf: &Self, input_types: Vec<WrappedSchema>, display_name: String) -> FFI_Result<WrappedSchema>,
pub coerce_types: unsafe extern "C" fn(udf: &Self, arg_types: Vec<WrappedSchema>) -> FFI_Result<Vec<WrappedSchema>>,
pub sort_options: FFI_Option<FFI_SortOptions>,
pub clone: unsafe extern "C" fn(udf: &Self) -> Self,
pub release: unsafe extern "C" fn(udf: &mut Self),
pub private_data: *mut c_void,
pub library_marker_id: extern "C" fn() -> usize,
}Expand description
A stable struct for sharing a WindowUDF across FFI boundaries.
Fields
name: StringFFI equivalent to the name of a WindowUDF
aliases: Vec<String>FFI equivalent to the aliases of a WindowUDF
volatility: FFI_VolatilityFFI equivalent to the volatility of a WindowUDF
partition_evaluator: unsafe extern "C" fn(udwf: &Self, args: FFI_PartitionEvaluatorArgs) -> FFI_Result<FFI_PartitionEvaluator>field: unsafe extern "C" fn(udwf: &Self, input_types: Vec<WrappedSchema>, display_name: String) -> FFI_Result<WrappedSchema>coerce_types: unsafe extern "C" fn(udf: &Self, arg_types: Vec<WrappedSchema>) -> FFI_Result<Vec<WrappedSchema>>Performs type coercion. To simply this interface, all UDFs are treated as having
user defined signatures, which will in turn call coerce_types to be called. This
call should be transparent to most users as the internal function performs the
appropriate calls on the underlying WindowUDF
sort_options: FFI_Option<FFI_SortOptions>clone: unsafe extern "C" fn(udf: &Self) -> SelfUsed to create a clone on the provider of the udf. This should only need to be called by the receiver of the udf.
release: unsafe extern "C" fn(udf: &mut Self)Release the memory of the private data when it is no longer being used.
private_data: *mut c_voidInternal data. This is only to be accessed by the provider of the udf.
A ForeignWindowUDF should never attempt to access this data.
library_marker_id: extern "C" fn() -> usizeUtility to identify when FFI objects are accessed locally through
the foreign interface. See crate::get_library_marker_id and
the crate’s README.md for more information.