Functions
- rvec_
wrapped_ to_ vec_ datatype - This is a utility function to convert an FFI friendly vector of
WrappedSchemato their equivalentDataType. - rvec_
wrapped_ to_ vec_ fieldref - This is a utility function to convert an FFI friendly vector of
WrappedSchemato their equivalentField. - vec_
datatype_ to_ rvec_ wrapped - This is a utility function to convert a slice of
DataTypeto its equivalent FFI friendly counterpart,WrappedSchema - vec_
fieldref_ to_ rvec_ wrapped - This is a utility function to convert a slice of
Fieldto its equivalent FFI friendly counterpart,WrappedSchema
Type Aliases
- FFIResult
- Convenience type for results passed through the FFI boundary. Since the
DataFusionErrorenum is complex and little value is gained from creating a FFI safe variant of it, we convert errors to strings when passing results back. These are converted back and forth using thedf_result,rresult, andrresult_returnmacros.