pub type FFIResult<T> = RResult<T, RString>;Expand description
Convenience type for results passed through the FFI boundary. Since the
DataFusionError enum is complex and little value is gained from creating
a FFI safe variant of it, we convert errors to strings when passing results
back. These are converted back and forth using the df_result, rresult,
and rresult_return macros.
Aliased Type
#[repr(u8)]pub enum FFIResult<T> {
ROk(T),
RErr(RString),
}